"""
OWLPy
~~~~~~~~~~~~~~~~~~~~~
An extension module to facilitate API Models and functionality.
:copyright: (c) 2019 Spydernaz
:license: MIT, see LICENSE for more details.
"""
from .Connection import PurviewConnection
